@@ -70,9 +70,17 @@ class DefaultCredentialsProvider(AlibabaCloudCredentialsProvider):
     def __init__(self):
         super(DefaultCredentialsProvider, self).__init__()
         self.user_configuration_providers = [
-            EnvironmentVariableCredentialsProvider(),
-            ProfileCredentialsProvider()
+            EnvironmentVariableCredentialsProvider()
         ]
+        if au.enable_oidc_credential:
+            self.user_configuration_providers.append(OIDCRoleArnCredentialProvider(
+                role_session_name=au.environment_role_session_name,
+                role_arn=au.environment_role_arn,
+                oidc_provider_arn=au.environment_oidc_provider_arn,
+                oidc_token_file_path=au.environment_oidc_token_file
+            ))
+
+        self.user_configuration_providers.append(ProfileCredentialsProvider())
         role_name = au.environment_ECSMeta_data
         if role_name is not None:
             self.user_configuration_providers.append(EcsRamRoleCredentialProvider(role_name))
@@ -193,7 +201,8 @@ class RamRoleArnCredentialProvider(AlibabaCloudCredentialsProvider):
         string_to_sign = ph.compose_string_to_sign("GET", tea_request.query)
         signature = ph.sign_string(string_to_sign, self.access_key_secret + "&")
         tea_request.query["Signature"] = signature
-        tea_request.headers['host'] = turl if turl else 'https://sts.aliyuncs.com'
+        tea_request.protocol = 'https'
+        tea_request.headers['host'] = turl if turl else 'sts.aliyuncs.com'
         # request
         response = TeaCore.do_action(tea_request)
         if response.status_code == 200:
@@ -217,7 +226,7 @@ class OIDCRoleArnCredentialProvider(AlibabaCloudCredentialsProvider):
                  oidc_token_file_path=None,
                  region_id=None,
                  policy=None, config=None):
-        self._verify_empty_args(config, access_key_id, access_key_secret)
+        self._verify_empty_args(config, role_arn, oidc_provider_arn, oidc_token_file_path)
         super(OIDCRoleArnCredentialProvider, self).__init__(config)
         self._set_arg('role_arn', role_arn)
         self._set_arg('oidc_provider_arn', oidc_provider_arn)
@@ -230,8 +239,6 @@ class OIDCRoleArnCredentialProvider(AlibabaCloudCredentialsProvider):
         else:
             raise CredentialException(
                 'The oidc_token_file_path does not exist and env ALIBABA_CLOUD_OIDC_TOKEN_FILE is none.')
-        self._set_arg('access_key_id', access_key_id)
-        self._set_arg('access_key_secret', access_key_secret)
         self._set_arg('region_id', region_id)
         self._set_arg('role_session_name', role_session_name)
         self._set_arg('policy', policy)
@@ -244,27 +251,22 @@ class OIDCRoleArnCredentialProvider(AlibabaCloudCredentialsProvider):
         oidc_token = au.get_private_key(self.oidc_token_file_path)
         tea_request = TeaRequest()
         tea_request.query = {
-            'Action': 'AssumeRole',
+            'Action': 'AssumeRoleWithOIDC',
             'Format': 'JSON',
             'Version': '2015-04-01',
             'DurationSeconds': str(self.duration_seconds),
             'RoleArn': self.role_arn,
             'OIDCProviderArn': self.oidc_provider_arn,
             'OIDCToken': oidc_token,
-            'AccessKeyId': self.access_key_id,
             'RegionId': self.region_id,
-            'RoleSessionName': self.role_session_name,
-            'SignatureMethod': 'HMAC-SHA1',
-            'SignatureVersion': '1.0'
+            'RoleSessionName': self.role_session_name if self.role_session_name else 'defaultSessionName'
         }
         tea_request.query["Timestamp"] = ph.get_iso_8061_date()
         tea_request.query["SignatureNonce"] = ph.get_uuid()
         if self.policy is not None:
             tea_request.query["Policy"] = self.policy
-        string_to_sign = ph.compose_string_to_sign("GET", tea_request.query)
-        signature = ph.sign_string(string_to_sign, self.access_key_secret + "&")
-        tea_request.query["Signature"] = signature
-        tea_request.headers['host'] = turl if turl else 'https://sts.aliyuncs.com'
+        tea_request.protocol = 'https'
+        tea_request.headers['host'] = turl if turl else 'sts.aliyuncs.com'
         # request
         response = TeaCore.do_action(tea_request)
         if response.status_code == 200:
@@ -310,7 +312,8 @@ class RsaKeyPairCredentialProvider(AlibabaCloudCredentialsProvider):
         str_to_sign = ph.compose_string_to_sign('GET', tea_request.query)
         signature = ph.sign_string(str_to_sign, self.access_key_id + '&')
         tea_request.query['Signature'] = signature
-        tea_request.headers['host'] = turl if turl else 'https://sts.aliyuncs.com'
+        tea_request.protocol = 'https'
+        tea_request.headers['host'] = turl if turl else 'sts.aliyuncs.com'
         # request
         response = TeaCore.do_action(tea_request)
         if response.status_code == 200:
