@@ -6,6 +6,7 @@ INI_ACCESS_KEY_IDSECRET = "access_key_secret"
 INI_TYPE = "type"
 INI_TYPE_RAM = "ecs_ram_role"
 INI_TYPE_ARN = "ram_role_arn"
+INI_TYPE_OIDC = "oidc_role_arn"
 INI_TYPE_KEY_PAIR = "rsa_key_pair"
 INI_PUBLIC_KEY_ID = "public_key_id"
 INI_PRIVATE_KEY_FILE = "private_key_file"
@@ -13,6 +14,8 @@ INI_PRIVATE_KEY = "private_key"
 INI_ROLE_NAME = "role_name"
 INI_ROLE_SESSION_NAME = "role_session_name"
 INI_ROLE_ARN = "role_arn"
+INI_OIDC_PROVIDER_ARN = "oidc_provider_arn"
+INI_OIDC_TOKEN_FILE_PATH = "oidc_token_file_path"
 INI_POLICY = "policy"
 TSC_VALID_TIME_SECONDS = 3600
 DEFAULT_REGION = "region_id"
@@ -21,5 +24,6 @@ ACCESS_KEY = "access_key"
 STS = "sts"
 ECS_RAM_ROLE = "ecs_ram_role"
 RAM_ROLE_ARN = "ram_role_arn"
+OIDC_ROLE_ARN = "oidc_role_arn"
 RSA_KEY_PAIR = "rsa_key_pair"
 BEARER = "bearer"
